
Welcome to cx_Freeze's documentation!
=====================================

**cx_Freeze** creates standalone executables from Python scripts, with the same
performance, is cross-platform and should work on any platform that Python_
itself works on.
Current version of **cx_Freeze** is 6.15 and its supports Python 3.7 to 3.11.

**cx_Freeze** is distributed under an open-source :ref:`license <license>`
(the PSF license).

Contents:

.. toctree::
   :maxdepth: 2

   installation.rst
   overview.rst
   script.rst
   setup_script.rst
   keywords.rst
   faq.rst
   releasenotes.rst
   versions.rst
   development/index.rst
   license.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _py2exe: https://pypi.org/project/py2exe/
.. _py2app: https://pypi.org/project/py2app/
.. _Python: https://www.python.org/
